@@ -62,7 +62,7 @@
 #define AKONADI_CALENDAR_CORE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef AKONADI_CALENDAR_CORE_NO_DEPRECATED
-#  define AKONADI_CALENDAR_CORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x6055a
+#  define AKONADI_CALENDAR_CORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x60600
 #endif
 #ifdef AKONADI_CALENDAR_CORE_NO_DEPRECATED_WARNINGS
 #  define AKONADI_CALENDAR_CORE_DEPRECATED_WARNINGS_SINCE 0
@@ -72,7 +72,7 @@
 #  ifdef AKONADI_CALENDAR_CORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define AKONADI_CALENDAR_CORE_DEPRECATED_WARNINGS_SINCE AKONADI_CALENDAR_CORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define AKONADI_CALENDAR_CORE_DEPRECATED_WARNINGS_SINCE 0x6055a
+#    define AKONADI_CALENDAR_CORE_DEPRECATED_WARNINGS_SINCE 0x60600
 #  endif
 #endif
 
